@@ -30,8 +30,8 @@ function(behavior,phaseX,v1){
   
   
   if (a=="y")
-  {write.csv(transdat,file = file.choose(new = T),row.names=FALSE)}
-  #{write.csv(transdat,file = tclvalue(tcl("tk_getSaveFile")),row.names=FALSE)}
+  #{write.csv(transdat,file = file.choose(new = T),row.names=FALSE)}
+  {write.csv(transdat,file = tclvalue(tkgetSaveFile()),row.names=FALSE)}
   
   print(transdat)
 }
