@@ -28,8 +28,7 @@ function(behavior,phaseX,ABxlab,ABylab, ABmain){
   instruct<-"You can add lines between phases by using the ABlines() function. You can add text by using the ABtext() function. You can also add a mean, median, sd line by using the ABstat() function." 
   strwrap(instruct) 
   
-  ab<-NULL
-  ab<<-recordPlot()
+  
   
   
 }
