@@ -1,13 +1,14 @@
 Gline <-
   function() {
+    targetindex<-dev.cur() 
+    targetindex<-recordPlot() 
+    
     yo<-readline("Y ordinate for your goal line  " )
 abline(h=yo,col="gray",lwd=3)
+
 u<-readline("accept line? (y/n) ")
 if (u=="n")
-{replayPlot(ab)}
-
-ab<-NULL
-ab<<-recordPlot()
-{assign('ab', recordPlot())}
+ 
+{replayPlot(targetindex)}
 
 }
\ No newline at end of file
